From 76272d4b587a53dca7a99106280480759c242222 Mon Sep 17 00:00:00 2001
From: Masahiko Sawada <sawada.mshk@gmail.com>
Date: Fri, 13 Dec 2024 16:55:52 -0800
Subject: [PATCH v7 7/8] tidstore.c: Add TidStoreNumBlocks API to get the
 number of blocks.

Author:
Reviewed-by:
Discussion: https://postgr.es/m/
Backpatch-through:
---
 src/backend/access/common/tidstore.c | 12 ++++++++++++
 src/include/access/tidstore.h        |  1 +
 2 files changed, 13 insertions(+)

diff --git a/src/backend/access/common/tidstore.c b/src/backend/access/common/tidstore.c
index 720bc86c266..e1614da9e89 100644
--- a/src/backend/access/common/tidstore.c
+++ b/src/backend/access/common/tidstore.c
@@ -588,6 +588,18 @@ TidStoreMemoryUsage(TidStore *ts)
 		return local_ts_memory_usage(ts->tree.local);
 }
 
+/*
+ * Return the number of entries in TidStore.
+ */
+BlockNumber
+TidStoreNumBlocks(TidStore *ts)
+{
+	if (TidStoreIsShared(ts))
+		return shared_ts_num_keys(ts->tree.shared);
+	else
+		return local_ts_num_keys(ts->tree.local);
+}
+
 /*
  * Return the DSA area where the TidStore lives.
  */
diff --git a/src/include/access/tidstore.h b/src/include/access/tidstore.h
index c886cef0f7d..fd739d20da1 100644
--- a/src/include/access/tidstore.h
+++ b/src/include/access/tidstore.h
@@ -51,6 +51,7 @@ extern int	TidStoreGetBlockOffsets(TidStoreIterResult *result,
 									int max_offsets);
 extern void TidStoreEndIterate(TidStoreIter *iter);
 extern size_t TidStoreMemoryUsage(TidStore *ts);
+extern BlockNumber TidStoreNumBlocks(TidStore *ts);
 extern dsa_pointer TidStoreGetHandle(TidStore *ts);
 extern dsa_area *TidStoreGetDSA(TidStore *ts);
 
-- 
2.43.5

